@@ -100,12 +100,12 @@ HMAC = SHA1( [ passcode, SHA1( [passcode, data ] ) );\n \
 
 #if 0
 %!test
-%! expected = [
+%! expected = double([
 %!   0xA9 0x99 0x3E 0x36 ...
 %!   0x47 0x06 0x81 0x6A ...
 %!   0xBA 0x3E 0x25 0x71 ...
 %!   0x78 0x50 0xC2 0x6C ...
-%!   0x9C 0xD0 0xD8 0x9D ];
+%!   0x9C 0xD0 0xD8 0x9D ]);
 %! result = SHA1(uint8("abc"));
 %! assert (result, expected)
 #endif
